@@ -1,4 +1,5 @@
 import logging
+import re
 from datetime import datetime
 from pathlib import Path
 from typing import Dict, List, Union
@@ -8,7 +9,7 @@ import xarray as xr
 from attrs import define, field
 
 from .data import ENUMERATED_TABLES, INVALID_STUBS_FILE
-from .data_handlers import apply_run_and_forecasted_time_filters
+from .data_handlers import apply_run_and_forecasted_time_filters, to_xarray
 from .forecast_type.validators import (
     validate_MTPASA_datetime_inputs,
     validate_P5MIN_datetime_inputs,
@@ -32,6 +33,10 @@ def _map_files_to_table(
     Translates output from `generate_sqlloader_filenames` to map filenames of interest
     to a queried table name.
 
+    Handles enumerated tables (e.g. `PREDISP_ALL_DATA`) by mapping enumerated filenames
+    to non-enumerated table type (which is used in the user query).
+    E.g. '...PREDISPATCHLOAD1' and '...PREDISPATCHLOAD2' mapped to 'LOAD'
+
     Args:
         forecast_start: Forecasts made at or after this datetime are queried.
         forecast_end: Forecasts made before or at this datetime are queried.
@@ -44,13 +49,26 @@ def _map_files_to_table(
     metadata_to_filename = generate_sqlloader_filenames(
         run_start, run_end, forecast_type, tables
     )
-    table_file_map = {}
+    if forecast_type in ENUMERATED_TABLES.keys():
+        enumerated_tables = [pair[0] for pair in ENUMERATED_TABLES[forecast_type]]
+    else:
+        enumerated_tables = []
+    table_file_map: Dict[str, List[str]] = {}
     for table in tables:
         filenames_to_map = list()
         for metadata in metadata_to_filename.keys():
             if metadata[2] == table:
                 filenames_to_map.append(metadata_to_filename[metadata])
-        table_file_map[table] = filenames_to_map
+        if (enum_base := re.match(r"([A-Z]*)[0-9]", table)) and enum_base.group(
+            1
+        ) in enumerated_tables:
+            map_table_name = enum_base.group(1)
+            if map_table_name in table_file_map.keys():
+                table_file_map[map_table_name].extend(filenames_to_map)
+            else:
+                table_file_map[map_table_name] = filenames_to_map
+        else:
+            table_file_map[table] = filenames_to_map
     return table_file_map
 
 
@@ -150,18 +168,22 @@ class DataCompiler:
         else:
             return []
 
-    def compile_raw_data_to_dataframe(self) -> None:
-        """Compiles data from :term:`raw_cache` to a :class:`pandas.DataFrame`
+    def compile_raw_data(self, data_format: str = "df") -> None:
+        """Compiles data from :term:`raw_cache` to a :class:`pandas.DataFrame` (default)
+        or to a :class:`xarray.Dataset`.
 
         This compiler will:
 
         - Skip invalid/corrupted files as recorded in `.invalid_aemo_files.txt`
         - Read :term:`raw_cache` parquet files and apply datetime filtering
+        - Convert :class:`DataFrame <pandas.DataFrame>` to :class:`xarray.Dataset`
 
+        Args:
+            data_format: Default "df" (:class:`pandas.DataFrame`). Other valid input is
+                "xr", which returns :class:`xarray.Dataset`s.
         Returns:
-            A single concatenated DataFrame if only one table type is requested.
-            Otherwise, returns a dictionary with concatenated DataFrames mapped to each
-            requested table type.
+            A dictionary with concatenated DataFrames/Datasets mapped to each requested
+            table type.
         Warning:
             Skips any files previously found to be invalid/corrupted and prints a
             warning
@@ -174,11 +196,18 @@ class DataCompiler:
         for table in file_to_table_map.keys():
             files = file_to_table_map[table]
             filtered_files = [file for file in files if file not in invalid_files]
-            if len(filtered_files) < len(files):
+            if not filtered_files:
+                raise ValueError(
+                    "Query failed as all files to be compiled were found to be"
+                    + " invalid/corrupt on previous download. You can force nemseer"
+                    + " to load these files by deleting them from "
+                    + ".invalid_aemo_files.txt"
+                )
+            elif len(filtered_files) < len(files):
                 logging.warning(
                     "Some files not compiled as these were found to be"
                     + " invalid/corrupt on previous download. You can force nemseer"
-                    + " to load this file by deleting it from "
+                    + " to load these files by deleting them from "
                     + ".invalid_aemo_files.txt"
                 )
             dfs = []
@@ -194,8 +223,17 @@ class DataCompiler:
                     self.forecast_type,
                 )
                 dfs.append(df.reset_index(drop=True))
-            if len(dfs) == 1:
-                table_to_df_map[table] = dfs.pop()
+            concat_df = pd.concat(dfs)
+            if any(concat_df.duplicated()):
+                logging.warning(
+                    "Duplicate rows detected whilst concatenating data. "
+                    + "Dropping these rows."
+                )
+                concat_df = concat_df.drop_duplicates()
+            if data_format == "xr":
+                logging.info(f"Converting {table} data to xarray.")
+                concat_data = to_xarray(concat_df, self.forecast_type)
             else:
-                table_to_df_map[table] = pd.concat(dfs, axis=0)
+                concat_data = concat_df
+            table_to_df_map[table] = concat_data
         self.compiled_data = table_to_df_map
